@@ -1,5 +1,5 @@
 #######################################################################
-# $Id: Term.pm,v 1.14 2010-11-30 20:57:53 dpchrist Exp $
+# $Id: Term.pm,v 1.15 2010-12-03 05:13:51 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
@@ -21,7 +21,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = ();
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.14 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.15 $ =~ /(\d+)/g);
 
 #######################################################################
 # uses:
@@ -38,7 +38,7 @@ Dpchrist::Term - terminal I/O routines
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.14 $.
+This documentation describes module revision $Revision: 1.15 $.
 
 
 This is alpha test level software
@@ -112,8 +112,6 @@ All of the subroutines may be imported by using the ':all' tag:
 
     use Dpchrist::Debug		qw( :all );
 
-See 'perldoc Export' for everything in between.
-
 
 =head1 INSTALLATION
 
@@ -132,13 +130,6 @@ Complete:
 
     $ cpan Bundle::Dpchrist
 
-The following warning may be safely ignored:
-
-    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
-    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
-    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
-    /usr/local/lib/site_perl .) at Makefile.PL line 22.
-
 
 =head2 PREREQUISITES
 
